# CHANGELOG

## 0.2.0

### Features

- TypeExpectError now accepts multiple expectations.

### Refactor

- Restructured project to the normal python-project view.
- Removed enum codes, replaced to string ones.
